==> AnnBuilder_1.3.3.tar.gz: AnnBuilder/man/homoPkgBuilder.Rd <==
\name{homoPkgBuilder}
\alias{homoPkgBuilder}
\alias{procHomoData}
\alias{getLL2IntID}
\alias{getIntIDMapping}
\alias{mapIntID}
\alias{mapOrgs}
\alias{writeRdaNMan}
\alias{mapPS}
\alias{getHomoPS}
\title{Functions to build a homology data package using data from NCBI}
\description{
  This function builds a data package that maps internal HomoloGene ids
  of an organism to LocusLink ids, UniGene ids, percent identity of the
  alignment, type of similarities, and url to the source of a curated
  orthology of organisms of all pairwise best matches based on data from
  \url{ftp://ftp.ncbi.nih.gov/pub/HomoloGene/hmlg.ftp}
}
\usage{
homoPkgBuilder(pkgName = "homology", pkgPath, version, author, url =
getSrcUrl("HG"))
procHomoData(url = getSrcUrl("HG"))
getLL2IntID(homoData, organism = "")
getIntIDMapping(homoData)
mapIntID(homoData)
mapOrgs(vect)
writeRdaNMan(homoData, pkgName, pkgPath, what)
mapPS(homoData, pkgName, pkgPath)
getHomoPS(entries)
}
\arguments{
  \item{pkgName}{\code{pkgName} a character string for the name of data
    package to be built}
  \item{pkgPath}{\code{pkgPath} a character string for the name of the
    directory where the created package will be stored}
  \item{version}{\code{version} a character string for the verion number
    of the package to be built}
  \item{author}{\code{author} a list with an author element for the name
    of the author and a maintainer element for the name and e-mail
    address of the maintainer of the package} 
  \item{url}{\code{url} the url to the ftp site from which the source data
    file can be obtained. The default value is
    url{ftp://ftp.ncbi.nih.gov/pub/HomoloGene/hmlg.ftp}}
  \item{homoData}{\code{homoData} a data frame that contains the homology
    data from the source}
  \item{organism}{\code{organism} a character string for the name of the
    organism of interest}
  \item{vect}{\code{vect} a vector of character strings}
  \item{what}{\code{what} a character string for the data environment to
    be created. i. e. HGID2LL, HGID2GB, ...}
  \item{entries}{\code{entries} a vector of character strings}
}
\details{
  procHomoData process the source data and put the data into a data
  frame that will be used later.

  getLL2IntID maps LocusLink ids to HomoloGene internal ids

  getIntIDMapping maps HomoloGene ids to ids include LocusLink ids,
  GneBank accession numbers, percent similarity values, type of
  similarities, and the url to the curated orthology.

  mapIntID captures the reverse mapping between reciprocal homologous
  genes.

  mapOrgs converts organism codes to scientific names.

  writeRdaNMan creates an rda file and the corresponding man page for a
  data environment.

  mapPS maps HomologGene Internal ids to homoPS objects generated using
  data from the source.

  getHomoPS creates a homoPS object using data passed as a vector.
}
\value{
  procHomoData, mapIntID, and getLL2IntID returns a matrix.

  getIntIDMapping returns an R environment with mappings between
  HomoloGene internal ids and mapped data.

  getHomoPS returns a homoPS object with slots filled with data passed.

  mapOrgs returns a vector of character strings.
}
\references{\url{ftp://ftp.ncbi.nih.gov/pub/HomoloGene/README}}
\author{Jianhua Zhang}
\note{The functions are part of the Bioconductor project at Dana-Farber
  Cancer Institute to provide Bioinformatics functionalities using R}

\seealso{\code{\link{ABPkgBuilder}}}
\examples{
# Examples are provided for only a few functions to avoid lengthy
# execution time
load(file.path(.path.package("AnnBuilder"), "data", "orgNameNCode.rda"),
         env = .GlobalEnv)
mapOrgs(c("10116", "10090", "9606"))
getHomoPS(c("9606", "10116", "B", "12345", "324322", "78.1"))
}
\keyword{manip}

==> AnnBuilder_1.4.2.tar.gz: AnnBuilder/man/homoPkgBuilder.Rd <==
\name{homoPkgBuilder}
\alias{homoPkgBuilder}
\alias{procHomoData}
\alias{getLL2IntID}
\alias{getIntIDMapping}
\alias{mapIntID}
\alias{mapOrgs}
\alias{writeRdaNMan}
\alias{mapPS}
\alias{getHomoPS}
\alias{getHomoDList}
\alias{getHomoData}
\alias{getHomoData}
\alias{getOrgNameNCode}
\alias{saveOrgNameNCode}
\alias{HomoData2List}
\title{Functions to build a homology data package using data from NCBI}
\description{
  This function builds a data package that maps internal HomoloGene ids
  of an organism to LocusLink ids, UniGene ids, percent identity of the
  alignment, type of similarities, and url to the source of a curated
  orthology of organisms of all pairwise best matches based on data from
  \url{ftp://ftp.ncbi.nih.gov/pub/HomoloGene/hmlg.ftp}
}
\usage{
homoPkgBuilder(pkgName = "homology", pkgPath, version, author, url =
getSrcUrl("HG"))
procHomoData(url = getSrcUrl("HG"))
getLL2IntID(homoData, organism = "")
mapOrgs(toMap, what = c("code","name"))
mapPS(url, pkgName, pkgPath)
getHomoDList(data)
getHomoData(entries)
getHomoData(entries)
getOrgNameNCode()
saveOrgNameNCode(pkgName, pkgPath, author)
HomoData2List(data)
}
\arguments{
  \item{pkgName}{\code{pkgName} a character string for the name of data
    package to be built}
  \item{pkgPath}{\code{pkgPath} a character string for the name of the
    directory where the created package will be stored}
  \item{version}{\code{version} a character string for the verion number
    of the package to be built}
  \item{author}{\code{author} a list with an author element for the name
    of the author and a maintainer element for the name and e-mail
    address of the maintainer of the package} 
  \item{url}{\code{url} the url to the ftp site from which the source data
    file can be obtained. The default value is
    url{ftp://ftp.ncbi.nih.gov/pub/HomoloGene/hmlg.ftp}}
  \item{homoData}{\code{homoData} a data frame that contains the homology
    data from the source}
  \item{organism}{\code{organism} a character string for the name of the
    organism of interest}
  \item{toMap}{\code{vect} a vector of character strings}
  \item{entries}{\code{entries} a vector of character strings}
  \item{data}{\code{data} a data matrix}
  \item{what}{\code{what} a character string that can either be "code"
    or "name"}
}
\details{
  procHomoData process the source data and put the data into a data
  frame that will be used later.

  getLL2IntID maps LocusLink ids to HomoloGene internal ids

  getIntIDMapping maps HomoloGene ids to ids include LocusLink ids,
  GneBank accession numbers, percent similarity values, type of
  similarities, and the url to the curated orthology.

  mapIntID captures the reverse mapping between reciprocal homologous
  genes.

  mapOrgs converts organism codes to scientific names.

  writeRdaNMan creates an rda file and the corresponding man page for a
  data environment.

  mapPS maps HomologGene Internal ids to homoPS objects generated using
  data from the source.

  getHomoPS creates a homoPS object using data passed as a vector.
}
\value{
  procHomoData, mapIntID, and getLL2IntID returns a matrix.

  getIntIDMapping returns an R environment with mappings between
  HomoloGene internal ids and mapped data.

  getHomoPS returns a homoPS object with slots filled with data passed.

  mapOrgs returns a vector of character strings.
}
\references{\url{ftp://ftp.ncbi.nih.gov/pub/HomoloGene/README}}
\author{Jianhua Zhang}
\note{The functions are part of the Bioconductor project at Dana-Farber
  Cancer Institute to provide Bioinformatics functionalities using R}

\seealso{\code{\link{ABPkgBuilder}}}
\examples{
# Examples are provided for only a few functions to avoid lengthy
# execution time

}
\keyword{manip}
